#! /bin/csh

# Run this script in the FluidProp root directory to
# prepare environment variables. Instead of running it
# in the FluidProp root directory itself, it is also
# possible to add the FluidProp directory as a
# command-line argument.
# Use this script with csh, tcsh or another 
# csh-related shell. Invoke with:
# source SetEnv_FluidProp.csh [<FluidProp directory>]
# ([] denotes an optional argument, <> an argument value)

if ("$1" == "") then
   setenv FLUIDPROP `pwd`
else
   setenv FLUIDPROP $1
endif
   
setenv FLUIDPROP_DATA ${FLUIDPROP}/share/fluidprop

# Storage of platform name
set unamestr1=`uname`
set unamestr2=`uname -m`
if ("$unamestr1" == "Linux") then
   if ("$unamestr2" == "i686") then
      setenv PLATFORM "Linux32"
   else if ( "$unamestr2" == "x86_64" ) then
      setenv PLATFORM "Linux"
   endif
else if ( "$unamestr1" == "Darwin" ) then
   setenv PLATFORM "macOS"
else
   setenv PLATFORM "unknown"
endif

if ( "$PLATFORM" == "Linux32" ) then
   if !($?LD_LIBRARY_PATH) then
      setenv LD_LIBRARY_PATH ${FLUIDPROP}/ifort_redist/ia32:${FLUIDPROP}/lib
   else
      setenv LD_LIBRARY_PATH ${LD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/ia32:${FLUIDPROP}/lib
   endif
else if ( "$PLATFORM" == "Linux" ) then
   if !($?LD_LIBRARY_PATH) then
      setenv LD_LIBRARY_PATH ${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib
   else
      setenv LD_LIBRARY_PATH ${LD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib
   endif
else if ( "$PLATFORM" == "macOS" ) then
   # DYLD_LIBRARY_PATH is used on MAC OS
   if !($?DYLD_LIBRARY_PATH) then
      setenv DYLD_LIBRARY_PATH ${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib
   else
      setenv DYLD_LIBRARY_PATH ${DYLD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib
   endif
endif

# Matlab PATH
setenv MATLABPATH ${FLUIDPROP}/plugins/matlab
