//============================================================================================!
//                                                                                            !
//  fstring       Johan Meijdam        Copyright (c) 2004-2008. All Rights Reserved.          !
//  =======                            Energy Technology Section, TU Delft.                   !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : fstring                                                                   !   
//                                                                                            !   
//  Description   : Fortran strings for C                                                     !
//                                                                                            !   
//  Contents      : - AllocFString                                                            !   
//                  - FreeFString                                                             !   
//                  - strcpyC2F                                                               !    
//                  - trimF2C                                                                 !    
//                  - untrimC2F                                                               !    
//                                                                                            !   
//  Creation date : 09-07-2008, Johan Meijdam, VORtech                                        !
//                                                                                            !   
//============================================================================================!

#ifndef _NL_ASIMPTOTE_FLUIDPROP_FSTRING_H
#define _NL_ASIMPTOTE_FLUIDPROP_FSTRING_H

// Allocate a Fortran String of length flen.
// Initialize with C String cstr.
char *AllocFString(size_t flen, const char *cstr);

// Deallocate a Fortran String.
void FreeFString(char* fstr);

// Copy contents of C String cstr to Fortran String fstr.
char *strcpyC2F (char *fstr, const char* cstr);
char *strncpyC2F(char *fstr, const char* cstr, size_t flen);

// Place a \0 character in Fortran String fstr so it can be used as a C String
char *trimF2C(char *fstr);

// Remove \0 characters from C String cstr so it's a Fortran String of length flen again.
// Cannot be used without first using trimF2C on the same string.
char *untrimC2F(char *cstr, size_t flen);

#endif // _NL_ASIMPTOTE_FLUIDPROP_FSTRING_H
