//============================================================================================!
//                                                                                            !
//  shared       Johan Meijdam        Copyright  2004-2008. All Rights Reserved.             !
//  ======                             Energy Technology Section, TU Delft.                   !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : shared                                                                    !   
//                                                                                            !   
//  Description   : Shared functionality for the API functions                                !
//                                                                                            !   
//  Contents      : 1. Constant error string "No errors"                                      !   
//                                                                                            !   
//  Creation date : 07-07-2008, Johan Meijdam, VORtech                                        !
//                                                                                            !   
//============================================================================================!

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include "shared.h"

// Default message in case of no errors
const char NO_ERRORS[] = "No errors";
const int MAX_PATH = 512;
char FLUIDPROP[512];
char FLUIDPROP_DATA[512];

const char* parse (char* line, const char* var)
{
  // parse as VARIABLE=VALUE
  const char* envval = strrchr(line, '=') + 1;
  const char* found = strstr(line, var);
  char * newline = strchr(line,'\n');

  if (newline)
    *newline = '\0';

  if (found && envval && found + strlen(var) + 1 == envval)
    return envval;
  else
    return NULL;
}

// initialize paths from the environment (if available)
void readenv()
{
   const char* envval;

   envval = getenv("FLUIDPROP");

   if (envval)
      strncpy(FLUIDPROP, envval, MAX_PATH);

   envval = getenv("FLUIDPROP_DATA");

   if (envval)
      strncpy(FLUIDPROP_DATA, envval, MAX_PATH);
}

// initialize paths from the configuration files
void readconfig(const char* filename)
{
   const char* result;
   const int   len_buffer=512;
   char        buffer[512];
   FILE*       config;

   // expand homedir path
   if (*filename == '~')
   {
     result = getenv("HOME");
     if (!result)
       return;

     strcpy(buffer, result);
     strcat(buffer, filename+1);
     config = fopen(buffer,"r");
   } else
   {
     config = fopen (filename,"r");
   }

   if (config == NULL)
     return;

    // find the environment variable definition
    while (1)
    {
      if (fgets(buffer, len_buffer, config) == NULL)
        break;

      result = parse(buffer, "FLUIDPROP");
      if (result)
        strncpy(FLUIDPROP, result, MAX_PATH);

      result = parse(buffer, "FLUIDPROP_DATA");
      if (result)
        strncpy(FLUIDPROP_DATA, result, MAX_PATH);
    }

   fclose(config);
}
