//============================================================================================!
//                                                                                            !
//  shared       Johan Meijdam         Copyright (c) 2004-2008. All Rights Reserved.          !
//  ======                             Energy Technology Section, TU Delft.                   !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : shared                                                                    !   
//                                                                                            !   
//  Description   : Shared functionality for the API functions                                !
//                                                                                            !   
//  Contents      : - Default No Error message                                                !   
//                  - Definitions of BOOL, TRUE and FALSE                                     !
//                                                                                            !   
//  Creation date : 07-07-2008, Johan Meijdam, VORtech                                        !
//                                                                                            !   
//============================================================================================!

#ifndef _NL_ASIMPTOTE_FLUIDPROP_SHARED_H
#define _NL_ASIMPTOTE_FLUIDPROP_SHARED_H

#include <stdio.h>

// define cross-platform macros
#ifdef _WIN32
   #define int32_t long
#else
   #include <sys/types.h>
   #define __stdcall	__attribute__((stdcall))
   #define __cdecl	__attribute__((cdecl))
#endif

// define calling conventions (default cdecl)
#define FP_C_CALL
#define FP_SO_CALL
#define FP_DYLIB_CALL

// hardcode dynamic library path for debugging purposes
#ifdef DEBUG
#define DEBUGPREFIX
#define DEBUGWARNING(fname) printf ("warning: symbol %s not found in library", #fname);
#define DEBUGELSE else
#else
#define DEBUGPREFIX
#define DEBUGWARNING(fname)
#define DEBUGELSE
#endif // DEBUG

// Default message in case of no errors
extern const char NO_ERRORS[];
extern char FLUIDPROP[];
extern char FLUIDPROP_DATA[];

#if defined __APPLE__

#define LOAD_DL(handle,name) \
  handle = dlopen( DEBUGPREFIX "lib" name ".dylib", RTLD_LAZY ); \
  if (!handle) \
     fprintf (stderr, "%s\n", dlerror()); \

#elif defined __linux__

#define LOAD_DL(handle,name) \
    handle = dlopen( DEBUGPREFIX "lib" name ".so", RTLD_LAZY ); \
    if (!handle) \
      fprintf (stderr, "%s\n", dlerror()); \

#endif


#endif // _NL_ASIMPTOTE_FLUIDPROP_SHARED_H

