//============================================================================================!
//                                                                                            !
//  FluidProp      Teus van der Stelt        Copyright (c) 2004-2010. All Rights Reserved.    !
//  =========      Piero Colonna             Energy Technology Section, TU Delft.             !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : FluidProp                                                                 !   
//                                                                                            !   
//  Description   : This module loads and provides access to the FluidProp library.           !
//                                                                                            !   
//  Creation date : 21-07-2008, Henk Seubers, VORtech                                         !
//                                                                                            !   
//============================================================================================!

#ifndef _NL_ASIMPTOTE_FLUIDPROP_FLUIDPROP_H
#define _NL_ASIMPTOTE_FLUIDPROP_FLUIDPROP_H

#include "size3264bits.h"

// ==================================================!
//  Procedures for object initialization and cleanup !
// ==================================================!

// Is library loaded? 
BOOL FP_C_CALL FC_FUNC(fluidprop_isinit_c,FLUIDPROP_ISINIT_C)(void);

// Load library
BOOL FP_C_CALL FC_FUNC(init_fluidprop_c,INIT_FLUIDPROP_C)(void);

// Create object 
void FP_C_CALL FC_FUNC(createobject_c, CREATEOBJECT_C) ( char* ModelName, char* ErrorMsg, 
SIZE_TYPE len_ModelName, SIZE_TYPE len_ErrorMsg);
 
// Unload library 
void FP_C_CALL FC_FUNC(uninit_fluidprop_c,UNINIT_FLUIDPROP_C)(void);

// Returns version array (4 longs)
void FP_C_CALL FC_FUNC(fluidprop_getversion_c,FLUIDPROP_GETVERSION_C) ( char* ModelName, int32_t *version, SIZE_TYPE len_ModelName);

void FP_C_CALL FC_FUNC(sublibtest_c, SUBLIBTEST_C)();

// Functions calculating thermodynamic properties
void FP_C_CALL FC_FUNC(fluidprop_setfluid_c, FLUIDPROP_SETFLUID_C) ( char* ModelName, 
int32_t* nComp, char* Comp, double* Conc, char* ErrorMsg, SIZE_TYPE len_ModelName, 
SIZE_TYPE len_Comp, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_getfluid_c, FLUIDPROP_GETFLUID_C) ( char* ModelName, 
int32_t* nComp, char* Comp, double* Conc, SIZE_TYPE len_ModelName, SIZE_TYPE len_Comp);

// Function for table setup
void FP_C_CALL FC_FUNC(fluidprop_settable_c, FLUIDPROP_SETTABLE_C)(char* TableName,
char* TableType, char* InterpolMethod, char* MeshName, char* SearchAlg, int32_t* phase,
char* ErrorMsg, SIZE_TYPE len_TableName, SIZE_TYPE len_TableType, SIZE_TYPE len_InterpolMethod, 
SIZE_TYPE len_MeshName, SIZE_TYPE len_SearchAlg, SIZE_TYPE len_ErrorMsg);

// Function for table setup
void FP_C_CALL FC_FUNC(fluidprop_settable_new_c, FLUIDPROP_SETTABLE_NEW_C)(char* TableName,
char* InputSpec, double* Input1_min, double* Input1_max, double* Input2_min, double* Input2_max,
double* MeshSpacing, char* TableType, char* IntPolMethod, char* SearchAlg, char* ErrorMsg, SIZE_TYPE len_TableName, 
SIZE_TYPE len_InputSpec, SIZE_TYPE len_TableType, SIZE_TYPE len_IntPolMethod, SIZE_TYPE len_SearchAlg, SIZE_TYPE len_ErrorMsg);

// Function for table use
void FP_C_CALL FC_FUNC(fluidprop_usetable_c, FLUIDPORP_USETABLE_C)( char* TableName, 
char* ErrorMsg, SIZE_TYPE len_TableName, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_getfluidnames_c, FLUIDPROP_GETFLUIDNAMES_C) ( char* 
LongShort, char* ModelName, int32_t* nFluids, char* FluidNames, char* ErrorMsg, 
SIZE_TYPE len_LongShort, SIZE_TYPE len_ModelName, SIZE_TYPE len_FluidNames, 
SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_allpropssat_c, FLUIDPROP_ALLPROPSSAT_C) ( char* 
InputSpec, double* Input1, double* Input2, double* P, double* T, double* v, double* d, 
double* h, double* s, double* u, double* q, double* x, double* y, double* cv, double* cp, 
double* c, double* alpha, double* beta, double* chi, double* fi, double* ksi, double* psi, 
double* zeta, double* theta, double* kappa, double* gamma, double* eta, double* lambda, 
double* d_liq,   double* d_vap, double* h_liq, double* h_vap, double* T_sat, double* 
dd_liq_dP, double* dd_vap_dP, double* dh_liq_dP, double* dh_vap_dP, double* dT_sat_dP, 
char* ErrorMsg, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_allprops_c, FLUIDPROP_ALLPROPS_C) ( char* InputSpec, 
double* Input1, double* Input2, double* P, double* T, double* v, double* d, double* h, 
double* s, double* u, double* q, double* x, double* y, double* cv, double* cp, double* c, 
double* alpha, double* beta, double* chi, double* fi, double* ksi, double* psi, double* 
zeta, double* theta, double* kappa, double* gamma, double* eta, double* lambda, char* 
ErrorMsg, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_allpropssu2_c, FLUIDPROP_ALLPROPSSU2_C)( char* InputSpec, 
double* Input1, double* Input2, double* P, double* T, double* d, double* s, double* u,      
double* cv, double* c2, double* alpha, double* beta, char* ErrorMsg, SIZE_TYPE len_InputSpec, 
SIZE_TYPE len_ErrorMsg); 

void FP_C_CALL FC_FUNC(fluidprop_allpropsjoe_c, FLUIDPROP_ALLPROPSJOE_C)( char* InputSpec, 
double* Input1, double* Input2, double* P, double* T, double* v, double* d, double* h, double* s, 
double* u, double* cv, double* cp, double* c, double* alpha, double* beta, double* zeta, double* 
eta, double* lambda, double* dlam_dT, double* dlam_drho, double* deta_dT, double* deta_drho, char* 
ErrorMsg, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_alltransprops_c, FLUIDPROP_ALLTRANSPROPS_C)( char* InputSpec, 
double* Input1, double* Input2, double* eta, double* eta_T, double* eta_rho, double* lambda, double* lambda_T, 
double* lambda_rho, double* sigma, char* ErrorMsg, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_solve_c, FLUIDPROP_SOLVE_C)( char* FuncSpec, double* FuncVal,      
      char* InputSpec, int32_t* TargetProp, double* FixedVal,       
      double* MinVal, double* MaxVal, double* Output, char* ErrorMsg, 
      SIZE_TYPE len_FuncSpec, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_pressure_c, FLUIDPROP_PRESSURE_C)( char* InputSpec, double* Input1, double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_temperature_c, FLUIDPROP_TEMPERATURE_C)( char* InputSpec, double* Input1,   double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_specvolume_c, FLUIDPROP_SPECVOLUME_C)( char* InputSpec, double* Input1,    double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_density_c, FLUIDPROP_DENSITY_C)( char* InputSpec, double* Input1,       double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_enthalpy_c, FLUIDPROP_ENTHALPY_C)( char* InputSpec, double* Input1,      double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_entropy_c, FLUIDPROP_ENTROPY_C)( char* InputSpec, double* Input1,       double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_intenergy_c, FLUIDPROP_INTENERGY_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_gibbsenergy_c, FLUIDPROP_GIBBSENERGY_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_vaporqual_c, FLUIDPROP_VAPORQUAL_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_liquidcmp_c, FLUIDPROP_LIQUIDCMP_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_vaporcmp_c, FLUIDPROP_VAPORCMP_C)( char* InputSpec, double* Input1,      double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_fugacoef_c, FLUIDPROP_FUGACOEF_C)( char* InputSpec, double* Input1,      double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_heatcapv_c, FLUIDPROP_HEATCAPV_C)( char* InputSpec, double* Input1,      double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_heatcapp_c, FLUIDPROP_HEATCAPP_C)( char* InputSpec, double* Input1,      double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_soundspeed_c, FLUIDPROP_SOUNDSPEED_C)( char* InputSpec, double* Input1,    double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_alpha_c, FLUIDPROP_ALPHA_C)( char* InputSpec, double* Input1,        double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_beta_c, FLUIDPROP_BETA_C)( char* InputSpec, double* Input1,          double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_chi_c, FLUIDPROP_CHI_C)( char* InputSpec, double* Input1,           double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_fi_c, FLUIDPROP_FI_C)( char* InputSpec, double* Input1,            double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_ksi_c, FLUIDPROP_KSI_C)( char* InputSpec, double* Input1,           double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_psi_c, FLUIDPROP_PSI_C)( char* InputSpec, double* Input1,           double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_zeta_c, FLUIDPROP_ZETA_C)( char* InputSpec, double* Input1,          double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_theta_c, FLUIDPROP_THETA_C)( char* InputSpec, double* Input1,         double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_kappa_c, FLUIDPROP_KAPPA_C)( char* InputSpec, double* Input1,         double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_gamma_c, FLUIDPROP_GAMMA_C)( char* InputSpec, double* Input1,         double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_viscosity_c, FLUIDPROP_VISCOSITY_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_thermcond_c, FLUIDPROP_THERMCOND_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_surftens_c, FLUIDPROP_SURFTENS_C)( char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_calcprop_c, FLUIDPROP_CALCPROP_C)( char* PropSpec, char* InputSpec, double* Input1,     double* Input2, double* Output, char* ErrorMsg,  SIZE_TYPE len_PropSpec, SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_mmol_c, FLUIDPROP_MMOL_C)( double* Output, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_tcrit_c, FLUIDPROP_TCRIT_C)( double* Output, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_pcrit_c, FLUIDPROP_PCRIT_C)( double* Output, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_tmin_c, FLUIDPROP_TMIN_C)( double* Output, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_tmax_c, FLUIDPROP_TMAX_C)( double* Output, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_allinfo_c, FLUIDPROP_ALLINFO_C)( double* M_mol, double* T_crit, double* P_crit, double* T_min, double* T_max, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_setunits_c, FLUIDPROP_SETUNITS_C)( char* UnitSet, char* MassOrMole, char* Properties, char* Units, char* ErrorMsg, 
                                    SIZE_TYPE len_UnitSet, SIZE_TYPE len_MassOrMole, SIZE_TYPE len_Properties, SIZE_TYPE len_Units, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(fluidprop_setrefstate_c, FLUIDPROP_SETREFSTATE_C)(double* T_ref, double* P_ref, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_setrefstate_nondim_c, FLUIDPROP_SETREFSTATE_NONDIM_C)(double* T_ref, double* P_ref, double* v_ref, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_zflow_vu_c, FLUIDPROP_ZFLOW_VU_C)( double* P, double* T, double* v, double* h, double* s, double* u, double* alpha, double* beta,
                                                                   double* chi, double* fi, double* zeta, double* gamma, char* ErrorMsg, SIZE_TYPE len_ErrorMsg) ;

void FP_C_CALL FC_FUNC(saturationline_c, FLUIDPROP_SATURATIONLINE_C) ( int32_t* nPnts, double* T, double* P, double* x, double* y, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(isoline_c, FLUIDPROP_ISOLINE_C) ( char* PropSpec, double* PropVal, char* RunSpec, char* CalcSpec, double* MinVal, double* MaxVal, int32_t* nPnts,
                                                        double* RunVal, double* CalcVal, char* ErrorMsg, SIZE_TYPE len_PropSpec, SIZE_TYPE len_RunSpec, SIZE_TYPE len_CalcSpec,
                                                        SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_capeopenderiv_c, FLUIDPROP_CAPEOPENDERIV_C)( char* InputSpec, double* Input1, double* Input2, double* v_der, double* h_der,
                                                                             double* s_der, double* G_der, double* lnphi_der, char* ErrorMsg,
                                                                             SIZE_TYPE len_InputSpec, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_stanmix_psat_k1_c, FLUIDPROP_STANMIX_PSAT_K1_C)( double* k1, double* T, double* Psat, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_stanmix_xy_a_alfa_c, FLUIDPROP_STANMIX_XY_A_ALFA_C)( double* Aij, double* Aji, double* alfa, double* P, double* T, double* x,
                                                                                     double* y, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_pcp_saft_xy_kij_c, FLUIDPROP_PCP_SAFT_XY_KIJ_C)( double* kij, double* P, double* T, double* x, double* y, char* ErrorMsg,
                                                                                 SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_pcp_saft_p_kij_c, FLUIDPROP_PCP_SAFT_P_KIJ_C)( double* kij, double* T, double* q, double* P, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_pcp_saft_t_kij_c, FLUIDPROP_PCP_SAFT_T_KIJ_C)( double* kij, double* P, double* q, double* T, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(fluidprop_pcp_saft_hsxy_mp_c, FLUIDPROP_PCP_SAFT_HSXY_MP_C)( double* P, double* T, double* MolPar, double* h_r, double* s_r, double* x, double* y, char* ErrorMsg,
                                                                                   SIZE_TYPE len_ErrorMsg);

void FP_C_CALL FC_FUNC(saturationline_c, SATURATIONLINE_C) ( int32_t* nPnts, double* T, double* P, double* x, double* y, char* ErrorMsg, SIZE_TYPE len_ErrorMsg);

#endif // _NL_ASIMPTOTE_FLUIDPROP_FLUIDPROP_H
